/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.pango;

import org.gnu.javagnome.Handle;

/**
 * The AttrString object is used to represent attributes with a string
 * value.
 */
public class AttrString extends Attribute 
{

	/**
	 */
	public String getValue(){
		return getValue(getHandle());
	}


    native static final protected String getValue (Handle obj);
}

